/**
 * @author MusikAnimal and others
 * @license GPL-2.0-or-later
 * @link https://gerrit.wikimedia.org/g/mediawiki/extensions/CodeMirror
 */
import { HighlightStyle } from '@codemirror/language';
import { Tag } from '@lezer/highlight';
import type { StreamParser } from '@codemirror/language';
/**
 * Configuration for the MediaWiki highlighting mode for CodeMirror.
 * This is a separate class mainly to keep static configuration out of
 * the logic in CodeMirrorModeMediaWiki.
 */
export declare const modeConfig: {
    /**
     * All HTML/XML tags permitted in MediaWiki Core.
     *
     * Extensions should use the CodeMirrorTagModes extension attribute to register tags
     * instead of adding them here.
     *
     * @see https://www.mediawiki.org/wiki/Extension:CodeMirror#Extension_integration
     */
    permittedHtmlTags: {
        b: boolean;
        bdi: boolean;
        del: boolean;
        i: boolean;
        ins: boolean;
        u: boolean;
        font: boolean;
        big: boolean;
        small: boolean;
        sub: boolean;
        sup: boolean;
        h1: boolean;
        h2: boolean;
        h3: boolean;
        h4: boolean;
        h5: boolean;
        h6: boolean;
        cite: boolean;
        code: boolean;
        em: boolean;
        s: boolean;
        strike: boolean;
        strong: boolean;
        tt: boolean;
        var: boolean;
        div: boolean;
        center: boolean;
        blockquote: boolean;
        q: boolean;
        ol: boolean;
        ul: boolean;
        dl: boolean;
        table: boolean;
        caption: boolean;
        pre: boolean;
        ruby: boolean;
        rb: boolean;
        rp: boolean;
        rt: boolean;
        rtc: boolean;
        p: boolean;
        span: boolean;
        abbr: boolean;
        dfn: boolean;
        kbd: boolean;
        samp: boolean;
        data: boolean;
        time: boolean;
        mark: boolean;
        br: boolean;
        wbr: boolean;
        hr: boolean;
        li: boolean;
        dt: boolean;
        dd: boolean;
        td: boolean;
        th: boolean;
        tr: boolean;
        noinclude: boolean;
        includeonly: boolean;
        onlyinclude: boolean;
    };
    /**
     * HTML tags that are only self-closing.
     */
    implicitlyClosedHtmlTags: Record<string, true>;
    /**
     * Mapping of MediaWiki-esque token identifiers to a standardized lezer highlighting tag.
     * Values are one of the default highlighting tags. The idea is to use as many default tags as
     * possible so that theming (such as dark mode) can be applied with minimal effort. The
     * semantic meaning of the tag may not really match how it is used, but as per CodeMirror docs,
     * this is fine. It's still better to make use of the standard tags in some way.
     *
     * Once we allow use of other themes, we may want to tweak these values for aesthetic reasons.
     * The values here can freely be changed. The actual CSS class used is defined further down
     * in highlightStyle().
     *
     * @see https://lezer.codemirror.net/docs/ref/#highlight.tags
     * @internal
     */
    tags: {
        apostrophes: string;
        apostrophesBold: string;
        apostrophesItalic: string;
        comment: string;
        doubleUnderscore: string;
        extLink: string;
        extLinkBracket: string;
        extLinkProtocol: string;
        extLinkText: string;
        hr: string;
        htmlTagAttribute: string;
        htmlTagBracket: string;
        htmlTagName: string;
        extTagAttribute: string;
        extTagBracket: string;
        extTagName: string;
        indenting: string;
        linkBracket: string;
        linkDelimiter: string;
        linkText: string;
        linkToSection: string;
        list: string;
        parserFunction: string;
        parserFunctionBracket: string;
        parserFunctionDelimiter: string;
        parserFunctionName: string;
        sectionHeader: string;
        sectionHeader1: string;
        sectionHeader2: string;
        sectionHeader3: string;
        sectionHeader4: string;
        sectionHeader5: string;
        sectionHeader6: string;
        signature: string;
        tableBracket: string;
        tableDefinition: string;
        tableDelimiter: string;
        template: string;
        templateArgumentName: string;
        templateBracket: string;
        templateDelimiter: string;
        templateName: string;
        templateVariable: string;
        templateVariableBracket: string;
        templateVariableName: string;
        section: string;
        em: string;
        error: string;
        extTag: string;
        extGround: string;
        freeExtLink: string;
        freeExtLinkProtocol: string;
        link: string;
        linkGround: string;
        linkPageName: string;
        mnemonic: string;
        pageName: string;
        skipFormatting: string;
        strong: string;
        tableCaption: string;
        templateGround: string;
        templateExtGround: string;
        templateLinkGround: string;
        templateVariableDelimiter: string;
        template2ExtGround: string;
        template2Ground: string;
        template3ExtGround: string;
        template3Ground: string;
        pre: string;
        nowiki: string;
    };
    /**
     * These are custom tokens (a.k.a. tags) that aren't mapped to any of the standardized tags.
     * Make sure these are also defined in tags() above.
     *
     * @see https://codemirror.net/docs/ref/#language.StreamParser.tokenTable
     * @see https://lezer.codemirror.net/docs/ref/#highlight.Tag%5Edefine
     */
    readonly tokenTable: Record<string, Tag>;
    /**
     * This defines the actual CSS class assigned to each tag/token.
     * Keep this in sync and in the same order as tags().
     *
     * @see https://codemirror.net/docs/ref/#language.TagStyle
     */
    getHighlightStyle(context: StreamParser<unknown>): HighlightStyle;
};
